@@ -57,9 +57,7 @@ async def test_slow_file(monkeypatch, unused_tcp_port):
 
     spam_task = asyncio.ensure_future(spam_client())
 
-    reader, writer = await asyncio.open_connection(
-        "127.0.0.1", port=unused_tcp_port
-    )
+    reader, writer = await asyncio.open_connection("127.0.0.1", port=unused_tcp_port)
 
     actual_contents = await reader.read()
     writer.close()
